package com.gxlu.ps.netcruise.md.buffer;

import com.gxlu.ps.netcruise.md.GlobalInstance;
import com.gxlu.ps.netcruise.md.util.Alarm;
import java.util.LinkedList;
import java.util.NoSuchElementException;
import org.apache.log4j.Logger;

/* loaded from: com_gxlu_ps_netcruise_md_buffer.jar:com/gxlu/ps/netcruise/md/buffer/AlarmQueue.class */
public class AlarmQueue {
    protected int maxLength;
    protected int id;
    protected AlarmFile alarmFile;
    protected Logger logger;
    private LinkedList queue = new LinkedList();
    protected int mode = 1;

    public AlarmQueue(int maxLength, int id, AlarmFile alarmFile) {
        this.logger = null;
        this.logger = GlobalInstance.getInstance().getLogger();
        this.maxLength = maxLength;
        this.id = id;
        this.alarmFile = alarmFile;
        this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("AlarmQueue[").append(id).append("]: init finished."))));
    }

    public synchronized void setMode(int mode) {
        this.mode = mode;
        switch (mode) {
            case 1:
                this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("alarm queue[").append(this.id).append("] mode change to 1."))));
                return;
            case 2:
                saveToFileAndClear();
                this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("alarm queue[").append(this.id).append("] mode change to 2."))));
                return;
            default:
                return;
        }
    }

    public int size() {
        return this.queue.size();
    }

    public synchronized void addAlarm(Alarm alarm) {
        this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("AlarmQueue[").append(this.id).append("].addAlarm is called."))));
        switch (this.mode) {
            case 1:
                this.queue.addLast(alarm);
                return;
            case 2:
                this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("AlarmQueue[").append(this.id).append("]: save an alarm to file."))));
                this.alarmFile.saveAlarm(alarm);
                return;
            default:
                return;
        }
    }

    public synchronized void addAlarms(LinkedList alarms) {
        this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("AlarmQueue[").append(this.id).append("].addAlarms is called."))));
        switch (this.mode) {
            case 1:
                this.queue.addAll(alarms);
                return;
            case 2:
                this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("AlarmQueue[").append(this.id).append("]: save alarms to file."))));
                this.alarmFile.saveAlarms(alarms);
                return;
            default:
                return;
        }
    }

    public synchronized Alarm removeAlarm() {
        this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("AlarmQueue[").append(this.id).append("].removeAlarm is called."))));
        Alarm alm = null;
        try {
            alm = (Alarm) this.queue.removeFirst();
        } catch (NoSuchElementException e) {
        }
        return alm;
    }

    public synchronized LinkedList removeAlarms() {
        this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("AlarmQueue[").append(this.id).append("].removeAlarms is called."))));
        LinkedList alarms = this.queue;
        this.queue = new LinkedList();
        return alarms;
    }

    public synchronized void clearAllAlarms() {
        this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("AlarmQueue[").append(this.id).append("].clearAllAlarms is called."))));
        this.queue.clear();
    }

    public synchronized void pushbackAlarm(Alarm alarm) {
        this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("AlarmQueue[").append(this.id).append("].pushbackAlarm is called."))));
        this.queue.addFirst(alarm);
    }

    public synchronized void pushbackAlarms(LinkedList alarms) {
        this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("AlarmQueue[").append(this.id).append("].pushbackAlarms is called."))));
        this.queue.addAll(0, alarms);
    }

    public synchronized void saveToFile() {
        this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("AlarmQueue[").append(this.id).append("].saveToFile is called."))));
        if (!this.queue.isEmpty()) {
            this.alarmFile.saveAlarms(this.queue);
        }
    }

    public synchronized void saveToFileAndClear() {
        this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("AlarmQueue[").append(this.id).append("].saveToFileAndClear is called."))));
        if (!this.queue.isEmpty()) {
            this.alarmFile.saveAlarms(this.queue);
            this.queue.clear();
        }
    }

    public synchronized void loadFromFile() {
        LinkedList tmpList;
        if (this.alarmFile.hasAlarms() && (tmpList = this.alarmFile.loadAlarms(this.maxLength / 2)) != null) {
            if (tmpList.size() == 0) {
            }
            this.queue.addAll(tmpList);
        }
    }

    public synchronized void loadAllFromFile() {
        LinkedList tmpList;
        this.logger.trace(String.valueOf(String.valueOf(new StringBuffer("AlarmQueue[").append(this.id).append("].loadAllFromFile is called."))));
        if (this.alarmFile.hasAlarms() && (tmpList = this.alarmFile.loadAlarms(-1)) != null) {
            if (tmpList != null) {
            }
            this.queue.addAll(tmpList);
        }
    }

    public boolean hasAlmInFile() {
        return this.alarmFile.hasAlarms();
    }
}
